pub struct Solid<'alpha> { /* private fields */ }Expand description
Solid color image
Implementations
sourceimpl<'a> Solid<'a>
impl<'a> Solid<'a>
sourcepub fn set_alpha_map<'alpha: 'a>(
self,
alpha_map: &'alpha Image<'_, 'static>,
x: i16,
y: i16
) -> Solid<'alpha>
pub fn set_alpha_map<'alpha: 'a>( self, alpha_map: &'alpha Image<'_, 'static>, x: i16, y: i16 ) -> Solid<'alpha>
Set an alpha map that will be used when this image is used as a src in a blit operation
sourcepub fn clear_alpha_map(self) -> Solid<'static>
pub fn clear_alpha_map(self) -> Solid<'static>
Clear a previously set alpha map
Methods from Deref<Target = ImageRef>
sourcepub fn set_repeat(&self, repeat: Repeat)
pub fn set_repeat(&self, repeat: Repeat)
Set the repeat operation for this image
sourcepub fn set_transform(
&self,
transform: impl Into<Transform>
) -> Result<(), OperationFailed>
pub fn set_transform( &self, transform: impl Into<Transform> ) -> Result<(), OperationFailed>
Apply the specified transform during sampling from this image
sourcepub fn clear_transform(&self) -> Result<(), OperationFailed>
pub fn clear_transform(&self) -> Result<(), OperationFailed>
Clear a previously applied transform
sourcepub fn set_clip_region(
&self,
region: Option<&Region16>
) -> Result<(), OperationFailed>
pub fn set_clip_region( &self, region: Option<&Region16> ) -> Result<(), OperationFailed>
Apply a clip region used during composition
sourcepub fn set_clip_region32(
&self,
region: Option<&Region32>
) -> Result<(), OperationFailed>
pub fn set_clip_region32( &self, region: Option<&Region32> ) -> Result<(), OperationFailed>
Apply a clip region used during composition
sourcepub fn set_dither(&self, dither: Dither)
pub fn set_dither(&self, dither: Dither)
Set the dither operation used during composition
sourcepub fn set_dither_offset(&self, offset_x: c_int, offset_y: c_int)
pub fn set_dither_offset(&self, offset_x: c_int, offset_y: c_int)
Set the dither offset
sourcepub fn set_filter(
&self,
filter: Filter,
filter_params: &[Fixed]
) -> Result<(), OperationFailed>
pub fn set_filter( &self, filter: Filter, filter_params: &[Fixed] ) -> Result<(), OperationFailed>
Set the filter operation used during composition
sourcepub fn set_has_client_clip(&self, client_clip: bool)
pub fn set_has_client_clip(&self, client_clip: bool)
Set whether the source clip was set by a client
sourcepub fn set_source_clipping(&self, source_clipping: bool)
pub fn set_source_clipping(&self, source_clipping: bool)
Set whether the clip applies when the image is used as a source
sourcepub fn component_alpha(&self) -> bool
pub fn component_alpha(&self) -> bool
Whether the image has component alpha or unified alpha
sourcepub fn set_component_alpha(&self, component_alpha: bool)
pub fn set_component_alpha(&self, component_alpha: bool)
Set whether the image has component alpha or unified alpha
sourcepub fn as_ptr(&self) -> *mut pixman_image_t
pub fn as_ptr(&self) -> *mut pixman_image_t
Access the raw image pointer